# Python-IQ-Sim

This repo is a python library for controlling starting stopping and managing simulations running in the Intelligent Quads Cloud.

## Installation

```bash
pip install python-iq-sim
```

## Generate Docs

```bash
pydoc-markdown -I iq_sim -m iq_sim --render-toc > docs/iq_sim.md
```

## Documentation Available 

https://intelligent-quads.gitbook.io/python-iq-sim-documentation/

